@@ -69,6 +69,7 @@ class CacheManager(BaseModel):
 
 
 NodeModel = T.TypeVar("NodeModel", bound="Node")
+ResolverType = T.TypeVar("ResolverType", bound="Resolver")
 
 
 class Node(BaseModel):
@@ -173,7 +174,12 @@ class Node(BaseModel):
         class Edges(BaseModel):
             pass
 
-        resolver: Resolver = None
+        resolver: T.Type[ResolverType]
+
+    @classmethod
+    @property
+    def resolver(cls) -> ResolverType:
+        return cls.GQL.resolver()
 
 
 from .resolver import Resolver
